@@ -31,6 +31,9 @@
 #define TP_ERROR_STR_NO_ANSWER "org.freedesktop.Telepathy.Error.NoAnswer"
 #define TP_ERROR_STR_DOES_NOT_EXIST "org.freedesktop.Telepathy.Error.DoesNotExist"
 #define TP_ERROR_STR_TERMINATED "org.freedesktop.Telepathy.Error.Terminated"
+#define TP_ERROR_STR_MEDIA_CODECS_INCOMPATIBLE "org.freedesktop.Telepathy.Error.Media.CodecsIncompatible"
+#define TP_ERROR_STR_MEDIA_UNSUPPORTED_TYPE "org.freedesktop.Telepathy.Error.Media.UnsupportedType"
+#define TP_ERROR_STR_MEDIA_STREAMING_ERROR "org.freedesktop.Telepathy.Error.Media.StreamingError"
 #define TP_ERROR_STR_CONNECTION_REFUSED "org.freedesktop.Telepathy.Error.ConnectionRefused"
 #define TP_ERROR_STR_CONNECTION_FAILED "org.freedesktop.Telepathy.Error.ConnectionFailed"
 #define TP_ERROR_STR_CONNECTION_LOST "org.freedesktop.Telepathy.Error.ConnectionLost"
