@@ -70,6 +70,37 @@ TpProxyPendingCall *tp_cli_channel_dispatcher_call_ensure_channel_with_hints (Tp
     GObject *weak_object);
 
 
+typedef void (*tp_cli_channel_dispatcher_callback_for_delegate_channels) (TpChannelDispatcher *proxy,
+    const GPtrArray *out_Delegated,
+    GHashTable *out_Not_Delegated,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_dispatcher_call_delegate_channels (TpChannelDispatcher *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_Channels,
+    gint64 in_User_Action_Time,
+    const gchar *in_Preferred_Handler,
+    tp_cli_channel_dispatcher_callback_for_delegate_channels callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_dispatcher_callback_for_present_channel) (TpChannelDispatcher *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_dispatcher_call_present_channel (TpChannelDispatcher *proxy,
+    gint timeout_ms,
+    const gchar *in_Channel,
+    gint64 in_User_Action_Time,
+    tp_cli_channel_dispatcher_callback_for_present_channel callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_channel_dispatcher_interface_operation_list_signal_callback_new_dispatch_operation) (TpChannelDispatcher *proxy,
     const gchar *arg_Dispatch_Operation,
     GHashTable *arg_Properties,
