@@ -305,6 +305,18 @@ TpProxySignalConnection *tp_cli_channel_interface_group_connect_to_handle_owners
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_interface_group_signal_callback_handle_owners_changed_detailed) (TpChannel *proxy,
+    GHashTable *arg_Added,
+    const GArray *arg_Removed,
+    GHashTable *arg_Identifiers,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_group_connect_to_handle_owners_changed_detailed (TpChannel *proxy,
+    tp_cli_channel_interface_group_signal_callback_handle_owners_changed_detailed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_channel_interface_group_signal_callback_self_handle_changed) (TpChannel *proxy,
     guint arg_Self_Handle,
     gpointer user_data, GObject *weak_object);
@@ -315,6 +327,17 @@ TpProxySignalConnection *tp_cli_channel_interface_group_connect_to_self_handle_c
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_interface_group_signal_callback_self_contact_changed) (TpChannel *proxy,
+    guint arg_Self_Handle,
+    const gchar *arg_Self_ID,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_group_connect_to_self_contact_changed (TpChannel *proxy,
+    tp_cli_channel_interface_group_signal_callback_self_contact_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_channel_interface_group_signal_callback_group_flags_changed) (TpChannel *proxy,
     guint arg_Added,
     guint arg_Removed,
@@ -825,6 +848,19 @@ gboolean tp_cli_channel_interface_password_run_provide_password (TpChannel *prox
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_channel_interface_room_config_callback_for_update_configuration) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_room_config_call_update_configuration (TpChannel *proxy,
+    gint timeout_ms,
+    GHashTable *in_Properties,
+    tp_cli_channel_interface_room_config_callback_for_update_configuration callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_channel_interface_sasl_authentication_signal_callback_sasl_status_changed) (TpChannel *proxy,
     guint arg_Status,
     const gchar *arg_Reason,
@@ -964,6 +1000,33 @@ TpProxySignalConnection *tp_cli_channel_interface_sms_connect_to_sms_channel_cha
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_interface_sms_callback_for_get_sms_length) (TpChannel *proxy,
+    guint out_Chunks_Required,
+    gint out_Remaining_Characters,
+    gint out_Estimated_Cost,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_sms_call_get_sms_length (TpChannel *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_Message,
+    tp_cli_channel_interface_sms_callback_for_get_sms_length callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_interface_sms_run_get_sms_length (TpChannel *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_Message,
+    guint *out_Chunks_Required,
+    gint *out_Remaining_Characters,
+    gint *out_Estimated_Cost,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_channel_interface_service_point_signal_callback_service_point_changed) (TpChannel *proxy,
     const GValueArray *arg_Service_Point,
     gpointer user_data, GObject *weak_object);
@@ -974,6 +1037,19 @@ TpProxySignalConnection *tp_cli_channel_interface_service_point_connect_to_servi
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_interface_subject_callback_for_set_subject) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_subject_call_set_subject (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Subject,
+    tp_cli_channel_interface_subject_callback_for_set_subject callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_channel_interface_tube_signal_callback_tube_channel_state_changed) (TpChannel *proxy,
     guint arg_State,
     gpointer user_data, GObject *weak_object);
