@@ -314,6 +314,48 @@ gboolean tp_cli_connection_run_request_handles (TpConnection *proxy,
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_callback_for_add_client_interest) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_call_add_client_interest (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar **in_Tokens,
+    tp_cli_connection_callback_for_add_client_interest callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_run_add_client_interest (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar **in_Tokens,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_callback_for_remove_client_interest) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_call_remove_client_interest (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar **in_Tokens,
+    tp_cli_connection_callback_for_remove_client_interest callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_run_remove_client_interest (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar **in_Tokens,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_connection_interface_aliasing_signal_callback_aliases_changed) (TpConnection *proxy,
     const GPtrArray *arg_Aliases,
     gpointer user_data, GObject *weak_object);
@@ -691,6 +733,139 @@ TpProxySignalConnection *tp_cli_connection_interface_cellular_connect_to_imsi_ch
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_connection_interface_client_types_signal_callback_client_types_updated) (TpConnection *proxy,
+    guint arg_Contact,
+    const gchar **arg_Client_Types,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_client_types_connect_to_client_types_updated (TpConnection *proxy,
+    tp_cli_connection_interface_client_types_signal_callback_client_types_updated callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_client_types_callback_for_get_client_types) (TpConnection *proxy,
+    GHashTable *out_Client_Types,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_client_types_call_get_client_types (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_client_types_callback_for_get_client_types callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_client_types_run_get_client_types (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GHashTable **out_Client_Types,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_client_types_callback_for_request_client_types) (TpConnection *proxy,
+    const gchar **out_Client_Types,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_client_types_call_request_client_types (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    tp_cli_connection_interface_client_types_callback_for_request_client_types callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_client_types_run_request_client_types (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    gchar ***out_Client_Types,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_blocking_signal_callback_blocked_contacts_changed) (TpConnection *proxy,
+    GHashTable *arg_Blocked_Contacts,
+    GHashTable *arg_Unblocked_Contacts,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_blocking_connect_to_blocked_contacts_changed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_blocking_signal_callback_blocked_contacts_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_blocking_callback_for_block_contacts) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_blocking_call_block_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    gboolean in_Report_Abusive,
+    tp_cli_connection_interface_contact_blocking_callback_for_block_contacts callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_blocking_run_block_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    gboolean in_Report_Abusive,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_blocking_callback_for_unblock_contacts) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_blocking_call_unblock_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_contact_blocking_callback_for_unblock_contacts callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_blocking_run_unblock_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_blocking_callback_for_request_blocked_contacts) (TpConnection *proxy,
+    GHashTable *out_Contacts,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_blocking_call_request_blocked_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    tp_cli_connection_interface_contact_blocking_callback_for_request_blocked_contacts callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_blocking_run_request_blocked_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    GHashTable **out_Contacts,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_connection_interface_contact_capabilities_signal_callback_contact_capabilities_changed) (TpConnection *proxy,
     GHashTable *arg_caps,
     gpointer user_data, GObject *weak_object);
@@ -745,6 +920,185 @@ gboolean tp_cli_connection_interface_contact_capabilities_run_get_contact_capabi
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_contact_groups_signal_callback_groups_changed) (TpConnection *proxy,
+    const GArray *arg_Contact,
+    const gchar **arg_Added,
+    const gchar **arg_Removed,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_groups_connect_to_groups_changed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_groups_signal_callback_groups_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_groups_signal_callback_groups_created) (TpConnection *proxy,
+    const gchar **arg_Names,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_groups_connect_to_groups_created (TpConnection *proxy,
+    tp_cli_connection_interface_contact_groups_signal_callback_groups_created callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_groups_signal_callback_group_renamed) (TpConnection *proxy,
+    const gchar *arg_Old_Name,
+    const gchar *arg_New_Name,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_groups_connect_to_group_renamed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_groups_signal_callback_group_renamed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_groups_signal_callback_groups_removed) (TpConnection *proxy,
+    const gchar **arg_Names,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_groups_connect_to_groups_removed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_groups_signal_callback_groups_removed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_groups_callback_for_set_contact_groups) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_groups_call_set_contact_groups (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    const gchar **in_Groups,
+    tp_cli_connection_interface_contact_groups_callback_for_set_contact_groups callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_groups_run_set_contact_groups (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    const gchar **in_Groups,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_groups_callback_for_set_group_members) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_groups_call_set_group_members (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    tp_cli_connection_interface_contact_groups_callback_for_set_group_members callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_groups_run_set_group_members (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_groups_callback_for_add_to_group) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_groups_call_add_to_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    tp_cli_connection_interface_contact_groups_callback_for_add_to_group callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_groups_run_add_to_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_groups_callback_for_remove_from_group) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_groups_call_remove_from_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    tp_cli_connection_interface_contact_groups_callback_for_remove_from_group callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_groups_run_remove_from_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_groups_callback_for_remove_group) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_groups_call_remove_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    tp_cli_connection_interface_contact_groups_callback_for_remove_group callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_groups_run_remove_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Group,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_groups_callback_for_rename_group) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_groups_call_rename_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Old_Name,
+    const gchar *in_New_Name,
+    tp_cli_connection_interface_contact_groups_callback_for_rename_group callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_groups_run_rename_group (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Old_Name,
+    const gchar *in_New_Name,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_connection_interface_contact_info_signal_callback_contact_info_changed) (TpConnection *proxy,
     guint arg_Contact,
     const GPtrArray *arg_ContactInfo,
@@ -844,6 +1198,171 @@ gboolean tp_cli_connection_interface_contact_info_run_set_contact_info (TpConnec
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_contact_list_signal_callback_contact_list_state_changed) (TpConnection *proxy,
+    guint arg_Contact_List_State,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_list_connect_to_contact_list_state_changed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_list_signal_callback_contact_list_state_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_list_signal_callback_contacts_changed_with_id) (TpConnection *proxy,
+    GHashTable *arg_Changes,
+    GHashTable *arg_Identifiers,
+    GHashTable *arg_Removals,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_list_connect_to_contacts_changed_with_id (TpConnection *proxy,
+    tp_cli_connection_interface_contact_list_signal_callback_contacts_changed_with_id callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_list_signal_callback_contacts_changed) (TpConnection *proxy,
+    GHashTable *arg_Changes,
+    const GArray *arg_Removals,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_list_connect_to_contacts_changed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_list_signal_callback_contacts_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_list_callback_for_get_contact_list_attributes) (TpConnection *proxy,
+    GHashTable *out_Attributes,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_list_call_get_contact_list_attributes (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar **in_Interfaces,
+    gboolean in_Hold,
+    tp_cli_connection_interface_contact_list_callback_for_get_contact_list_attributes callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_list_run_get_contact_list_attributes (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar **in_Interfaces,
+    gboolean in_Hold,
+    GHashTable **out_Attributes,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_list_callback_for_request_subscription) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_list_call_request_subscription (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    const gchar *in_Message,
+    tp_cli_connection_interface_contact_list_callback_for_request_subscription callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_list_run_request_subscription (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    const gchar *in_Message,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_list_callback_for_authorize_publication) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_list_call_authorize_publication (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_contact_list_callback_for_authorize_publication callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_list_run_authorize_publication (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_list_callback_for_remove_contacts) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_list_call_remove_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_contact_list_callback_for_remove_contacts callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_list_run_remove_contacts (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_list_callback_for_unsubscribe) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_list_call_unsubscribe (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_contact_list_callback_for_unsubscribe callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_list_run_unsubscribe (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_list_callback_for_unpublish) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_list_call_unpublish (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_contact_list_callback_for_unpublish callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_list_run_unpublish (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_connection_interface_contacts_callback_for_get_contact_attributes) (TpConnection *proxy,
     GHashTable *out_Attributes,
     const GError *error, gpointer user_data,
@@ -949,6 +1468,105 @@ gboolean tp_cli_connection_interface_location_run_set_location (TpConnection *pr
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_mail_notification_signal_callback_mails_received) (TpConnection *proxy,
+    const GPtrArray *arg_Mails,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_mail_notification_connect_to_mails_received (TpConnection *proxy,
+    tp_cli_connection_interface_mail_notification_signal_callback_mails_received callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_mail_notification_signal_callback_unread_mails_changed) (TpConnection *proxy,
+    guint arg_Count,
+    const GPtrArray *arg_Mails_Added,
+    const gchar **arg_Mails_Removed,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_mail_notification_connect_to_unread_mails_changed (TpConnection *proxy,
+    tp_cli_connection_interface_mail_notification_signal_callback_unread_mails_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_mail_notification_callback_for_request_inbox_url) (TpConnection *proxy,
+    const GValueArray *out_URL,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_mail_notification_call_request_inbox_url (TpConnection *proxy,
+    gint timeout_ms,
+    tp_cli_connection_interface_mail_notification_callback_for_request_inbox_url callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_mail_notification_run_request_inbox_url (TpConnection *proxy,
+    gint timeout_ms,
+    GValueArray **out_URL,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_mail_notification_callback_for_request_mail_url) (TpConnection *proxy,
+    const GValueArray *out_URL,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_mail_notification_call_request_mail_url (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_ID,
+    const GValue *in_URL_Data,
+    tp_cli_connection_interface_mail_notification_callback_for_request_mail_url callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_mail_notification_run_request_mail_url (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_ID,
+    const GValue *in_URL_Data,
+    GValueArray **out_URL,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_power_saving_signal_callback_power_saving_changed) (TpConnection *proxy,
+    gboolean arg_Active,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_power_saving_connect_to_power_saving_changed (TpConnection *proxy,
+    tp_cli_connection_interface_power_saving_signal_callback_power_saving_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_power_saving_callback_for_set_power_saving) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_power_saving_call_set_power_saving (TpConnection *proxy,
+    gint timeout_ms,
+    gboolean in_Activate,
+    tp_cli_connection_interface_power_saving_callback_for_set_power_saving callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_power_saving_run_set_power_saving (TpConnection *proxy,
+    gint timeout_ms,
+    gboolean in_Activate,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_connection_interface_presence_signal_callback_presence_update) (TpConnection *proxy,
     GHashTable *arg_Presence,
     gpointer user_data, GObject *weak_object);
