@@ -61,6 +61,18 @@ gboolean tp_cli_dbus_peer_run_get_machine_id (gpointer proxy,
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_dbus_properties_signal_callback_properties_changed) (TpProxy *proxy,
+    const gchar *arg_Interface_Name,
+    GHashTable *arg_Changed_Properties,
+    const gchar **arg_Invalidated_Properties,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_dbus_properties_connect_to_properties_changed (gpointer proxy,
+    tp_cli_dbus_properties_signal_callback_properties_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_dbus_properties_callback_for_get) (TpProxy *proxy,
     const GValue *out_Value,
     const GError *error, gpointer user_data,
