@@ -464,8 +464,15 @@ tp_svc_channel_interface_group_return_from_remove_members_with_reason (DBusGMeth
 void tp_svc_channel_interface_group_emit_handle_owners_changed (gpointer instance,
     GHashTable *arg_Added,
     const GArray *arg_Removed);
+void tp_svc_channel_interface_group_emit_handle_owners_changed_detailed (gpointer instance,
+    GHashTable *arg_Added,
+    const GArray *arg_Removed,
+    GHashTable *arg_Identifiers);
 void tp_svc_channel_interface_group_emit_self_handle_changed (gpointer instance,
     guint arg_Self_Handle);
+void tp_svc_channel_interface_group_emit_self_contact_changed (gpointer instance,
+    guint arg_Self_Handle,
+    const gchar *arg_Self_ID);
 void tp_svc_channel_interface_group_emit_group_flags_changed (gpointer instance,
     guint arg_Added,
     guint arg_Removed);
@@ -676,6 +683,51 @@ void tp_svc_channel_interface_password_emit_password_flags_changed (gpointer ins
     guint arg_Added,
     guint arg_Removed);
 
+typedef struct _TpSvcChannelInterfaceRoom TpSvcChannelInterfaceRoom;
+
+typedef struct _TpSvcChannelInterfaceRoomClass TpSvcChannelInterfaceRoomClass;
+
+GType tp_svc_channel_interface_room_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM \
+  (tp_svc_channel_interface_room_get_type ())
+#define TP_SVC_CHANNEL_INTERFACE_ROOM(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM, TpSvcChannelInterfaceRoom))
+#define TP_IS_SVC_CHANNEL_INTERFACE_ROOM(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM))
+#define TP_SVC_CHANNEL_INTERFACE_ROOM_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM, TpSvcChannelInterfaceRoomClass))
+
+
+
+typedef struct _TpSvcChannelInterfaceRoomConfig TpSvcChannelInterfaceRoomConfig;
+
+typedef struct _TpSvcChannelInterfaceRoomConfigClass TpSvcChannelInterfaceRoomConfigClass;
+
+GType tp_svc_channel_interface_room_config_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM_CONFIG \
+  (tp_svc_channel_interface_room_config_get_type ())
+#define TP_SVC_CHANNEL_INTERFACE_ROOM_CONFIG(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM_CONFIG, TpSvcChannelInterfaceRoomConfig))
+#define TP_IS_SVC_CHANNEL_INTERFACE_ROOM_CONFIG(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM_CONFIG))
+#define TP_SVC_CHANNEL_INTERFACE_ROOM_CONFIG_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_ROOM_CONFIG, TpSvcChannelInterfaceRoomConfigClass))
+
+
+typedef void (*tp_svc_channel_interface_room_config_update_configuration_impl) (TpSvcChannelInterfaceRoomConfig *self,
+    GHashTable *in_Properties,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_room_config_implement_update_configuration (TpSvcChannelInterfaceRoomConfigClass *klass, tp_svc_channel_interface_room_config_update_configuration_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_room_config_return_from_update_configuration (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_room_config_return_from_update_configuration (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+
 typedef struct _TpSvcChannelInterfaceSASLAuthentication TpSvcChannelInterfaceSASLAuthentication;
 
 typedef struct _TpSvcChannelInterfaceSASLAuthenticationClass TpSvcChannelInterfaceSASLAuthenticationClass;
@@ -779,6 +831,28 @@ GType tp_svc_channel_interface_sms_get_type (void);
   (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SMS, TpSvcChannelInterfaceSMSClass))
 
 
+typedef void (*tp_svc_channel_interface_sms_get_sms_length_impl) (TpSvcChannelInterfaceSMS *self,
+    const GPtrArray *in_Message,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_sms_implement_get_sms_length (TpSvcChannelInterfaceSMSClass *klass, tp_svc_channel_interface_sms_get_sms_length_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_sms_return_from_get_sms_length (DBusGMethodInvocation *context,
+    guint out_Chunks_Required,
+    gint out_Remaining_Characters,
+    gint out_Estimated_Cost);
+static inline void
+tp_svc_channel_interface_sms_return_from_get_sms_length (DBusGMethodInvocation *context,
+    guint out_Chunks_Required,
+    gint out_Remaining_Characters,
+    gint out_Estimated_Cost)
+{
+  dbus_g_method_return (context,
+      out_Chunks_Required,
+      out_Remaining_Characters,
+      out_Estimated_Cost);
+}
+
 void tp_svc_channel_interface_sms_emit_sms_channel_changed (gpointer instance,
     gboolean arg_SMSChannel);
 
@@ -816,6 +890,35 @@ GType tp_svc_channel_interface_service_point_get_type (void);
 void tp_svc_channel_interface_service_point_emit_service_point_changed (gpointer instance,
     const GValueArray *arg_Service_Point);
 
+typedef struct _TpSvcChannelInterfaceSubject TpSvcChannelInterfaceSubject;
+
+typedef struct _TpSvcChannelInterfaceSubjectClass TpSvcChannelInterfaceSubjectClass;
+
+GType tp_svc_channel_interface_subject_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_INTERFACE_SUBJECT \
+  (tp_svc_channel_interface_subject_get_type ())
+#define TP_SVC_CHANNEL_INTERFACE_SUBJECT(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SUBJECT, TpSvcChannelInterfaceSubject))
+#define TP_IS_SVC_CHANNEL_INTERFACE_SUBJECT(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SUBJECT))
+#define TP_SVC_CHANNEL_INTERFACE_SUBJECT_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SUBJECT, TpSvcChannelInterfaceSubjectClass))
+
+
+typedef void (*tp_svc_channel_interface_subject_set_subject_impl) (TpSvcChannelInterfaceSubject *self,
+    const gchar *in_Subject,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_subject_implement_set_subject (TpSvcChannelInterfaceSubjectClass *klass, tp_svc_channel_interface_subject_set_subject_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_subject_return_from_set_subject (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_subject_return_from_set_subject (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+
 typedef struct _TpSvcChannelInterfaceTube TpSvcChannelInterfaceTube;
 
 typedef struct _TpSvcChannelInterfaceTubeClass TpSvcChannelInterfaceTubeClass;
