@@ -199,6 +199,32 @@ tp_svc_connection_return_from_request_handles (DBusGMethodInvocation *context,
       out_Handles);
 }
 
+typedef void (*tp_svc_connection_add_client_interest_impl) (TpSvcConnection *self,
+    const gchar **in_Tokens,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_implement_add_client_interest (TpSvcConnectionClass *klass, tp_svc_connection_add_client_interest_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_return_from_add_client_interest (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_return_from_add_client_interest (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_remove_client_interest_impl) (TpSvcConnection *self,
+    const gchar **in_Tokens,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_implement_remove_client_interest (TpSvcConnectionClass *klass, tp_svc_connection_remove_client_interest_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_return_from_remove_client_interest (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_return_from_remove_client_interest (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
 void tp_svc_connection_emit_self_handle_changed (gpointer instance,
     guint arg_Self_Handle);
 void tp_svc_connection_emit_new_channel (gpointer instance,
@@ -544,6 +570,118 @@ GType tp_svc_connection_interface_cellular_get_type (void);
 void tp_svc_connection_interface_cellular_emit_imsi_changed (gpointer instance,
     const gchar *arg_IMSI);
 
+typedef struct _TpSvcConnectionInterfaceClientTypes TpSvcConnectionInterfaceClientTypes;
+
+typedef struct _TpSvcConnectionInterfaceClientTypesClass TpSvcConnectionInterfaceClientTypesClass;
+
+GType tp_svc_connection_interface_client_types_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_CLIENT_TYPES \
+  (tp_svc_connection_interface_client_types_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_CLIENT_TYPES(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CLIENT_TYPES, TpSvcConnectionInterfaceClientTypes))
+#define TP_IS_SVC_CONNECTION_INTERFACE_CLIENT_TYPES(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CLIENT_TYPES))
+#define TP_SVC_CONNECTION_INTERFACE_CLIENT_TYPES_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CLIENT_TYPES, TpSvcConnectionInterfaceClientTypesClass))
+
+
+typedef void (*tp_svc_connection_interface_client_types_get_client_types_impl) (TpSvcConnectionInterfaceClientTypes *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_client_types_implement_get_client_types (TpSvcConnectionInterfaceClientTypesClass *klass, tp_svc_connection_interface_client_types_get_client_types_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_client_types_return_from_get_client_types (DBusGMethodInvocation *context,
+    GHashTable *out_Client_Types);
+static inline void
+tp_svc_connection_interface_client_types_return_from_get_client_types (DBusGMethodInvocation *context,
+    GHashTable *out_Client_Types)
+{
+  dbus_g_method_return (context,
+      out_Client_Types);
+}
+
+typedef void (*tp_svc_connection_interface_client_types_request_client_types_impl) (TpSvcConnectionInterfaceClientTypes *self,
+    guint in_Contact,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_client_types_implement_request_client_types (TpSvcConnectionInterfaceClientTypesClass *klass, tp_svc_connection_interface_client_types_request_client_types_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_client_types_return_from_request_client_types (DBusGMethodInvocation *context,
+    const gchar **out_Client_Types);
+static inline void
+tp_svc_connection_interface_client_types_return_from_request_client_types (DBusGMethodInvocation *context,
+    const gchar **out_Client_Types)
+{
+  dbus_g_method_return (context,
+      out_Client_Types);
+}
+
+void tp_svc_connection_interface_client_types_emit_client_types_updated (gpointer instance,
+    guint arg_Contact,
+    const gchar **arg_Client_Types);
+
+typedef struct _TpSvcConnectionInterfaceContactBlocking TpSvcConnectionInterfaceContactBlocking;
+
+typedef struct _TpSvcConnectionInterfaceContactBlockingClass TpSvcConnectionInterfaceContactBlockingClass;
+
+GType tp_svc_connection_interface_contact_blocking_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_BLOCKING \
+  (tp_svc_connection_interface_contact_blocking_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_BLOCKING(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_BLOCKING, TpSvcConnectionInterfaceContactBlocking))
+#define TP_IS_SVC_CONNECTION_INTERFACE_CONTACT_BLOCKING(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_BLOCKING))
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_BLOCKING_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_BLOCKING, TpSvcConnectionInterfaceContactBlockingClass))
+
+
+typedef void (*tp_svc_connection_interface_contact_blocking_block_contacts_impl) (TpSvcConnectionInterfaceContactBlocking *self,
+    const GArray *in_Contacts,
+    gboolean in_Report_Abusive,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_blocking_implement_block_contacts (TpSvcConnectionInterfaceContactBlockingClass *klass, tp_svc_connection_interface_contact_blocking_block_contacts_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_blocking_return_from_block_contacts (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_blocking_return_from_block_contacts (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_blocking_unblock_contacts_impl) (TpSvcConnectionInterfaceContactBlocking *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_blocking_implement_unblock_contacts (TpSvcConnectionInterfaceContactBlockingClass *klass, tp_svc_connection_interface_contact_blocking_unblock_contacts_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_blocking_return_from_unblock_contacts (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_blocking_return_from_unblock_contacts (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_blocking_request_blocked_contacts_impl) (TpSvcConnectionInterfaceContactBlocking *self,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_blocking_implement_request_blocked_contacts (TpSvcConnectionInterfaceContactBlockingClass *klass, tp_svc_connection_interface_contact_blocking_request_blocked_contacts_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_blocking_return_from_request_blocked_contacts (DBusGMethodInvocation *context,
+    GHashTable *out_Contacts);
+static inline void
+tp_svc_connection_interface_contact_blocking_return_from_request_blocked_contacts (DBusGMethodInvocation *context,
+    GHashTable *out_Contacts)
+{
+  dbus_g_method_return (context,
+      out_Contacts);
+}
+
+void tp_svc_connection_interface_contact_blocking_emit_blocked_contacts_changed (gpointer instance,
+    GHashTable *arg_Blocked_Contacts,
+    GHashTable *arg_Unblocked_Contacts);
+
 typedef struct _TpSvcConnectionInterfaceContactCapabilities TpSvcConnectionInterfaceContactCapabilities;
 
 typedef struct _TpSvcConnectionInterfaceContactCapabilitiesClass TpSvcConnectionInterfaceContactCapabilitiesClass;
@@ -591,6 +729,116 @@ tp_svc_connection_interface_contact_capabilities_return_from_get_contact_capabil
 void tp_svc_connection_interface_contact_capabilities_emit_contact_capabilities_changed (gpointer instance,
     GHashTable *arg_caps);
 
+typedef struct _TpSvcConnectionInterfaceContactGroups TpSvcConnectionInterfaceContactGroups;
+
+typedef struct _TpSvcConnectionInterfaceContactGroupsClass TpSvcConnectionInterfaceContactGroupsClass;
+
+GType tp_svc_connection_interface_contact_groups_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_GROUPS \
+  (tp_svc_connection_interface_contact_groups_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_GROUPS(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_GROUPS, TpSvcConnectionInterfaceContactGroups))
+#define TP_IS_SVC_CONNECTION_INTERFACE_CONTACT_GROUPS(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_GROUPS))
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_GROUPS_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_GROUPS, TpSvcConnectionInterfaceContactGroupsClass))
+
+
+typedef void (*tp_svc_connection_interface_contact_groups_set_contact_groups_impl) (TpSvcConnectionInterfaceContactGroups *self,
+    guint in_Contact,
+    const gchar **in_Groups,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_groups_implement_set_contact_groups (TpSvcConnectionInterfaceContactGroupsClass *klass, tp_svc_connection_interface_contact_groups_set_contact_groups_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_groups_return_from_set_contact_groups (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_groups_return_from_set_contact_groups (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_groups_set_group_members_impl) (TpSvcConnectionInterfaceContactGroups *self,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_groups_implement_set_group_members (TpSvcConnectionInterfaceContactGroupsClass *klass, tp_svc_connection_interface_contact_groups_set_group_members_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_groups_return_from_set_group_members (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_groups_return_from_set_group_members (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_groups_add_to_group_impl) (TpSvcConnectionInterfaceContactGroups *self,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_groups_implement_add_to_group (TpSvcConnectionInterfaceContactGroupsClass *klass, tp_svc_connection_interface_contact_groups_add_to_group_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_groups_return_from_add_to_group (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_groups_return_from_add_to_group (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_groups_remove_from_group_impl) (TpSvcConnectionInterfaceContactGroups *self,
+    const gchar *in_Group,
+    const GArray *in_Members,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_groups_implement_remove_from_group (TpSvcConnectionInterfaceContactGroupsClass *klass, tp_svc_connection_interface_contact_groups_remove_from_group_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_groups_return_from_remove_from_group (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_groups_return_from_remove_from_group (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_groups_remove_group_impl) (TpSvcConnectionInterfaceContactGroups *self,
+    const gchar *in_Group,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_groups_implement_remove_group (TpSvcConnectionInterfaceContactGroupsClass *klass, tp_svc_connection_interface_contact_groups_remove_group_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_groups_return_from_remove_group (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_groups_return_from_remove_group (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_groups_rename_group_impl) (TpSvcConnectionInterfaceContactGroups *self,
+    const gchar *in_Old_Name,
+    const gchar *in_New_Name,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_groups_implement_rename_group (TpSvcConnectionInterfaceContactGroupsClass *klass, tp_svc_connection_interface_contact_groups_rename_group_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_groups_return_from_rename_group (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_groups_return_from_rename_group (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+void tp_svc_connection_interface_contact_groups_emit_groups_changed (gpointer instance,
+    const GArray *arg_Contact,
+    const gchar **arg_Added,
+    const gchar **arg_Removed);
+void tp_svc_connection_interface_contact_groups_emit_groups_created (gpointer instance,
+    const gchar **arg_Names);
+void tp_svc_connection_interface_contact_groups_emit_group_renamed (gpointer instance,
+    const gchar *arg_Old_Name,
+    const gchar *arg_New_Name);
+void tp_svc_connection_interface_contact_groups_emit_groups_removed (gpointer instance,
+    const gchar **arg_Names);
+
 typedef struct _TpSvcConnectionInterfaceContactInfo TpSvcConnectionInterfaceContactInfo;
 
 typedef struct _TpSvcConnectionInterfaceContactInfoClass TpSvcConnectionInterfaceContactInfoClass;
@@ -668,6 +916,114 @@ void tp_svc_connection_interface_contact_info_emit_contact_info_changed (gpointe
     guint arg_Contact,
     const GPtrArray *arg_ContactInfo);
 
+typedef struct _TpSvcConnectionInterfaceContactList TpSvcConnectionInterfaceContactList;
+
+typedef struct _TpSvcConnectionInterfaceContactListClass TpSvcConnectionInterfaceContactListClass;
+
+GType tp_svc_connection_interface_contact_list_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_LIST \
+  (tp_svc_connection_interface_contact_list_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_LIST(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_LIST, TpSvcConnectionInterfaceContactList))
+#define TP_IS_SVC_CONNECTION_INTERFACE_CONTACT_LIST(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_LIST))
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_LIST_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_LIST, TpSvcConnectionInterfaceContactListClass))
+
+
+typedef void (*tp_svc_connection_interface_contact_list_get_contact_list_attributes_impl) (TpSvcConnectionInterfaceContactList *self,
+    const gchar **in_Interfaces,
+    gboolean in_Hold,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_list_implement_get_contact_list_attributes (TpSvcConnectionInterfaceContactListClass *klass, tp_svc_connection_interface_contact_list_get_contact_list_attributes_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_list_return_from_get_contact_list_attributes (DBusGMethodInvocation *context,
+    GHashTable *out_Attributes);
+static inline void
+tp_svc_connection_interface_contact_list_return_from_get_contact_list_attributes (DBusGMethodInvocation *context,
+    GHashTable *out_Attributes)
+{
+  dbus_g_method_return (context,
+      out_Attributes);
+}
+
+typedef void (*tp_svc_connection_interface_contact_list_request_subscription_impl) (TpSvcConnectionInterfaceContactList *self,
+    const GArray *in_Contacts,
+    const gchar *in_Message,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_list_implement_request_subscription (TpSvcConnectionInterfaceContactListClass *klass, tp_svc_connection_interface_contact_list_request_subscription_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_list_return_from_request_subscription (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_list_return_from_request_subscription (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_list_authorize_publication_impl) (TpSvcConnectionInterfaceContactList *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_list_implement_authorize_publication (TpSvcConnectionInterfaceContactListClass *klass, tp_svc_connection_interface_contact_list_authorize_publication_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_list_return_from_authorize_publication (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_list_return_from_authorize_publication (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_list_remove_contacts_impl) (TpSvcConnectionInterfaceContactList *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_list_implement_remove_contacts (TpSvcConnectionInterfaceContactListClass *klass, tp_svc_connection_interface_contact_list_remove_contacts_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_list_return_from_remove_contacts (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_list_return_from_remove_contacts (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_list_unsubscribe_impl) (TpSvcConnectionInterfaceContactList *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_list_implement_unsubscribe (TpSvcConnectionInterfaceContactListClass *klass, tp_svc_connection_interface_contact_list_unsubscribe_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_list_return_from_unsubscribe (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_list_return_from_unsubscribe (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_list_unpublish_impl) (TpSvcConnectionInterfaceContactList *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_list_implement_unpublish (TpSvcConnectionInterfaceContactListClass *klass, tp_svc_connection_interface_contact_list_unpublish_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_list_return_from_unpublish (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_list_return_from_unpublish (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+void tp_svc_connection_interface_contact_list_emit_contact_list_state_changed (gpointer instance,
+    guint arg_Contact_List_State);
+void tp_svc_connection_interface_contact_list_emit_contacts_changed_with_id (gpointer instance,
+    GHashTable *arg_Changes,
+    GHashTable *arg_Identifiers,
+    GHashTable *arg_Removals);
+void tp_svc_connection_interface_contact_list_emit_contacts_changed (gpointer instance,
+    GHashTable *arg_Changes,
+    const GArray *arg_Removals);
+
 typedef struct _TpSvcConnectionInterfaceContacts TpSvcConnectionInterfaceContacts;
 
 typedef struct _TpSvcConnectionInterfaceContactsClass TpSvcConnectionInterfaceContactsClass;
@@ -766,6 +1122,91 @@ void tp_svc_connection_interface_location_emit_location_updated (gpointer instan
     guint arg_Contact,
     GHashTable *arg_Location);
 
+typedef struct _TpSvcConnectionInterfaceMailNotification TpSvcConnectionInterfaceMailNotification;
+
+typedef struct _TpSvcConnectionInterfaceMailNotificationClass TpSvcConnectionInterfaceMailNotificationClass;
+
+GType tp_svc_connection_interface_mail_notification_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_MAIL_NOTIFICATION \
+  (tp_svc_connection_interface_mail_notification_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_MAIL_NOTIFICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_MAIL_NOTIFICATION, TpSvcConnectionInterfaceMailNotification))
+#define TP_IS_SVC_CONNECTION_INTERFACE_MAIL_NOTIFICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_MAIL_NOTIFICATION))
+#define TP_SVC_CONNECTION_INTERFACE_MAIL_NOTIFICATION_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_MAIL_NOTIFICATION, TpSvcConnectionInterfaceMailNotificationClass))
+
+
+typedef void (*tp_svc_connection_interface_mail_notification_request_inbox_url_impl) (TpSvcConnectionInterfaceMailNotification *self,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_mail_notification_implement_request_inbox_url (TpSvcConnectionInterfaceMailNotificationClass *klass, tp_svc_connection_interface_mail_notification_request_inbox_url_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_mail_notification_return_from_request_inbox_url (DBusGMethodInvocation *context,
+    const GValueArray *out_URL);
+static inline void
+tp_svc_connection_interface_mail_notification_return_from_request_inbox_url (DBusGMethodInvocation *context,
+    const GValueArray *out_URL)
+{
+  dbus_g_method_return (context,
+      out_URL);
+}
+
+typedef void (*tp_svc_connection_interface_mail_notification_request_mail_url_impl) (TpSvcConnectionInterfaceMailNotification *self,
+    const gchar *in_ID,
+    const GValue *in_URL_Data,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_mail_notification_implement_request_mail_url (TpSvcConnectionInterfaceMailNotificationClass *klass, tp_svc_connection_interface_mail_notification_request_mail_url_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_mail_notification_return_from_request_mail_url (DBusGMethodInvocation *context,
+    const GValueArray *out_URL);
+static inline void
+tp_svc_connection_interface_mail_notification_return_from_request_mail_url (DBusGMethodInvocation *context,
+    const GValueArray *out_URL)
+{
+  dbus_g_method_return (context,
+      out_URL);
+}
+
+void tp_svc_connection_interface_mail_notification_emit_mails_received (gpointer instance,
+    const GPtrArray *arg_Mails);
+void tp_svc_connection_interface_mail_notification_emit_unread_mails_changed (gpointer instance,
+    guint arg_Count,
+    const GPtrArray *arg_Mails_Added,
+    const gchar **arg_Mails_Removed);
+
+typedef struct _TpSvcConnectionInterfacePowerSaving TpSvcConnectionInterfacePowerSaving;
+
+typedef struct _TpSvcConnectionInterfacePowerSavingClass TpSvcConnectionInterfacePowerSavingClass;
+
+GType tp_svc_connection_interface_power_saving_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_POWER_SAVING \
+  (tp_svc_connection_interface_power_saving_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_POWER_SAVING(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_POWER_SAVING, TpSvcConnectionInterfacePowerSaving))
+#define TP_IS_SVC_CONNECTION_INTERFACE_POWER_SAVING(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_POWER_SAVING))
+#define TP_SVC_CONNECTION_INTERFACE_POWER_SAVING_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_POWER_SAVING, TpSvcConnectionInterfacePowerSavingClass))
+
+
+typedef void (*tp_svc_connection_interface_power_saving_set_power_saving_impl) (TpSvcConnectionInterfacePowerSaving *self,
+    gboolean in_Activate,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_power_saving_implement_set_power_saving (TpSvcConnectionInterfacePowerSavingClass *klass, tp_svc_connection_interface_power_saving_set_power_saving_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_power_saving_return_from_set_power_saving (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_power_saving_return_from_set_power_saving (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+void tp_svc_connection_interface_power_saving_emit_power_saving_changed (gpointer instance,
+    gboolean arg_Active);
+
 typedef struct _TpSvcConnectionInterfacePresence TpSvcConnectionInterfacePresence;
 
 typedef struct _TpSvcConnectionInterfacePresenceClass TpSvcConnectionInterfacePresenceClass;
