@@ -25,6 +25,7 @@
 #include <glib-object.h>
 
 #include <telepathy-glib/base-client.h>
+#include <telepathy-glib/defs.h>
 
 G_BEGIN_DECLS
 
@@ -78,7 +79,9 @@ TpBaseClient * tp_simple_observer_new (TpDBusDaemon *dbus,
     gboolean uniquify,
     TpSimpleObserverObserveChannelsImpl callback,
     gpointer user_data,
-    GDestroyNotify destroy);
+    GDestroyNotify destroy)
+    _TP_GNUC_DEPRECATED_FOR (tp_simple_observer_new_with_factory);
+
 
 TpBaseClient *tp_simple_observer_new_with_am (
     TpAccountManager *account_manager,
@@ -89,6 +92,15 @@ TpBaseClient *tp_simple_observer_new_with_am (
     gpointer user_data,
     GDestroyNotify destroy);
 
+TpBaseClient *tp_simple_observer_new_with_factory (
+    TpSimpleClientFactory *factory,
+    gboolean recover,
+    const gchar *name,
+    gboolean uniquify,
+    TpSimpleObserverObserveChannelsImpl callback,
+    gpointer user_data,
+    GDestroyNotify destroy);
+
 G_END_DECLS
 
 #endif
